@@ -110,7 +110,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 }]
                 pub async fn payment_webhook(
                     req_ctx: Arc<RequestContext<ServerContext>>,
-                    body: TypedBody<serde_json::Value>,
+                    body: TypedBody<String>,
                 ) -> Result<HttpResponseOk<()>, HttpError> {
                     let internal_ctx = req_ctx
                         .context()
